==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/items/angels-copper.lua <==
data:extend(
{
  {
    type = "item",
    name = "processed-copper",
    icon = "__angelssmelting__/graphics/icons/processed-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-copper",
    icon = "__angelssmelting__/graphics/icons/pellet-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "anode-copper",
    icon = "__angelssmelting__/graphics/icons/anode-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-copper",
    icon = "__angelssmelting__/graphics/icons/ingot-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-copper",
    icon = "__angelssmelting__/graphics/icons/powder-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "ea",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-copper",
    icon = "__angelssmelting__/graphics/icons/molten-copper.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-copper",
    icon = "__angelssmelting__/graphics/icons/plate-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-wire-coil-copper",
    icon = "__angelssmelting__/graphics/icons/wire-coil-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "g",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-wire-copper",
    icon = "__angelssmelting__/graphics/icons/wire-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "h",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-copper",
    icon = "__angelssmelting__/graphics/icons/roll-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "i",
    stack_size = 200
  },
}
)

==> angelssmelting_0.4.3.zip: angelssmelting_0.4.3/prototypes/items/angels-copper.lua <==
data:extend(
{
  {
    type = "item",
    name = "processed-copper",
    icon = "__angelssmelting__/graphics/icons/processed-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-copper",
    icon = "__angelssmelting__/graphics/icons/pellet-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "anode-copper",
    icon = "__angelssmelting__/graphics/icons/anode-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-copper",
    icon = "__angelssmelting__/graphics/icons/ingot-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-copper",
    icon = "__angelssmelting__/graphics/icons/powder-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper",
    order = "ea",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-copper",
    icon = "__angelssmelting__/graphics/icons/molten-copper.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 154/255, g = 101/255, b = 86/255},
    flow_color = {r = 154/255, g = 101/255, b = 86/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-copper",
    icon = "__angelssmelting__/graphics/icons/plate-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-copper",
    icon = "__angelssmelting__/graphics/icons/roll-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-wire-coil-copper",
    icon = "__angelssmelting__/graphics/icons/wire-coil-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-wire-copper",
    icon = "__angelssmelting__/graphics/icons/wire-copper.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-copper-casting",
    order = "d",
    stack_size = 200
  },

}
)
